<?php
/*
Plugin Name: Auto Product Restock for Woo
Description: Automatically updates product stock status on a specified date.
Version: 1.1.0
Author: Xristos Avgeros
Author URI: https://xristosavgeros.com/
Text Domain: auto-product-restock-for-woo
Domain Path: /languages
Requires at least: 5.0
Tested up to: 6.7.2
Requires PHP: 7.0
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// Define plugin constants
define('NCWCAPR_VERSION', '1.1.0');
define('NCWCAPR_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('NCWCAPR_PLUGIN_URL', plugin_dir_url(__FILE__));

// Load plugin text domain
add_action('plugins_loaded', 'ncwcapr_restock_load_textdomain');
function ncwcapr_restock_load_textdomain() {
    load_plugin_textdomain('auto-product-restock-for-woo', false, dirname(plugin_basename(__FILE__)) . '/languages');
}

// Add settings link on plugin page
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'ncwcapr_restock_add_settings_link');
function ncwcapr_restock_add_settings_link($links) {
    $settings_link = '<a href="admin.php?page=apr-auto-restock-settings">' . esc_html__('Settings', 'auto-product-restock-for-woo') . '</a>';
    array_unshift($links, $settings_link);
    return $links;
}

// Include core files
require_once NCWCAPR_PLUGIN_DIR . 'includes/class-apr-auto-restock.php';
require_once NCWCAPR_PLUGIN_DIR . 'includes/class-apr-auto-restock-settings.php';
require_once NCWCAPR_PLUGIN_DIR . 'includes/class-apr-recurring-restock.php'; 
require_once NCWCAPR_PLUGIN_DIR . 'includes/class-apr-dashboard-widget.php';
require_once NCWCAPR_PLUGIN_DIR . 'includes/class-apr-admin-pages.php';

// Initialize the plugin
add_action('plugins_loaded', 'ncwcapr_restock_init');
function ncwcapr_restock_init() {
    if (class_exists('WooCommerce')) {
        new NCWCAPR_Auto_Restock();
        new NCWCAPR_Auto_Restock_Settings();
        new NCWCAPR_Recurring_Restock();
        new NCWCAPR_Dashboard_Widget();
        new NCWCAPR_Admin_Pages();
    }
}

// Clear scheduled event on plugin deactivation
register_deactivation_hook(__FILE__, 'ncwcapr_restock_clear_event');
function ncwcapr_restock_clear_event() {
    wp_clear_scheduled_hook('ncwcapr_restock_check_dates');
}

// Create required directories on activation
register_activation_hook(__FILE__, 'ncwcapr_restock_activate');
function ncwcapr_restock_activate() {
    // Ensure plugin directories exist
    $dirs = array(
        NCWCAPR_PLUGIN_DIR . 'css',
        NCWCAPR_PLUGIN_DIR . 'js',
    );
    
    foreach ($dirs as $dir) {
        if (!file_exists($dir)) {
            wp_mkdir_p($dir);
        }
    }
    
    // Add default plugin settings
    if (!get_option('ncwcapr_restock_display_position')) {
        update_option('ncwcapr_restock_display_position', 'woocommerce_single_product_summary');
    }
    
    if (!get_option('ncwcapr_restock_cron_schedule')) {
        update_option('ncwcapr_restock_cron_schedule', 4);
    }
    
    if (!get_option('ncwcapr_restock_enable_logging')) {
        update_option('ncwcapr_restock_enable_logging', 'no');
    }
    
    // Schedule the initial restock check
    if (!wp_next_scheduled('ncwcapr_restock_check_dates')) {
        wp_schedule_event(time(), 'hourly', 'ncwcapr_restock_check_dates');
    }
}